--====================================================--
-- REQUIRE LOADER.LUA
--====================================================--

loader = require ("loader")

--====================================================--
-- TOOGLE DEBUG
--====================================================--

--loader.debug = true

--====================================================--
-- GLOBALS
--====================================================--

_W = display.contentWidth
_H = display.contentHeight

--====================================================--
-- INFORMATION
--====================================================--

print ()
print ( "----------------------------------------------------------------------------")
print ( " - Welcome to the Loader Class, this is for advanced management of your app." )
print ( " - Please take a look on the samples here to understand how it works." )
print ( " - You will be able to: build object oriented apps; load/unload modules, images and audio; execute functions dynamically; create and control timers;" )
print ( " - Also, error messages will be shown on both Terminal and Device, debug messages only at Terminal but you need to turn it on with: loader.debug = true" )
print ( "----------------------------------------------------------------------------")
print ()
--
local label = display.newText ( "Please read main.lua", 0 , 0 , native.systemFontBold, 30)
label.x = _W / 2
label.y = _H / 2

--====================================================--
-- SAMPLES
--====================================================--

----------------------------------------------------------------------------------------------------------------
-- Load and Unload Images
----------------------------------------------------------------------------------------------------------------
--
-- This sample shows how to load and unload an image.
-- With this, Corona will not try to load it again.
--
----------------------------------------------------------------------------------------------------------------

--[[
--loader.debug = true
print()
--
print ( "Texture: " .. system.getInfo( "textureMemoryUsed" ) )
loader.loadImage ( "car.jpg", 200, 100 )
collectgarbage( "collect" )
print ( "Texture: " .. system.getInfo( "textureMemoryUsed" ) )
--
loader.loadImage ( "car.jpg", 50, 50 )
collectgarbage( "collect" )
print ( "Texture: " .. system.getInfo( "textureMemoryUsed" ) )
--
loader.unloadImage ( "car.jpg" )
collectgarbage( "collect" )
print ( "Texture: " .. system.getInfo( "textureMemoryUsed" ) )
--]]



----------------------------------------------------------------------------------------------------------------
-- Lazy Load Images
----------------------------------------------------------------------------------------------------------------
--
-- This sample shows how to load a bunch of images on
-- your code using a table. With this, you might prevent
-- some crashes because the images will be loaded lazy.
--
----------------------------------------------------------------------------------------------------------------

--[[
--loader.debug = true
print()
--
local loadDelay = 20
--
local tabImages = { 
	{ name="car.jpg", width=100, height=900 },
	{ name="car.jpg", width=200, height=800 },
	{ name="car.jpg", width=300, height=700 },
	{ name="car.jpg", width=400, height=600 },
	{ name="car.jpg", width=500, height=500 },
	{ name="car.jpg", width=600, height=400 },
	{ name="car.jpg", width=700, height=300 },
	{ name="car.jpg", width=800, height=200 },
	{ name="car.jpg", width=900, height=100 }
}
--
local idx = 1
--
local function loadImages ( event )
	loader.loadImage ( tabImages[idx].name, 
	                   tabImages[idx].width, 
	                   tabImages[idx].height )
	idx = idx + 1
end
--
local loadTimer = timer.performWithDelay ( loadDelay, loadImages, table.maxn(tabImages) )
--]]



----------------------------------------------------------------------------------------------------------------
-- Load, Play and Unload Audio
----------------------------------------------------------------------------------------------------------------
--
-- This sample shows how to load, play and unload an audio.
-- With this, Corona will not try to load it again.
--
----------------------------------------------------------------------------------------------------------------

--[[
--loader.debug = true
print ()
--
loader.loadAudio ( "bouncing_aif.aif" )
--
loader.loadAudio ( "bouncing_aif.aif" )
--
loader.playAudio ( "bouncing_aif.aif" )
--
local function onComplete ( event )
	audio.stop()
	loader.unloadAudio ( "bouncing_aif.aif" )
end
--
local stopAudio = timer.performWithDelay ( 1000, onComplete )
--
--]]



----------------------------------------------------------------------------------------------------------------
-- Call Function
----------------------------------------------------------------------------------------------------------------
--
-- This sample shows how to dynamically execute a function
-- of a module or an object.
--
----------------------------------------------------------------------------------------------------------------

--[[
--loader.debug = true
print()
--
local carImg, carName, carWidth, carHeight = "car.jpg", "auto", 200, 100
--
local car1 = loader.newGroup( "car" , {image=carImg, name="Ford",  width=carWidth, height=carHeight} )
local car2 = loader.newGroup( "car" , {image=carImg, name="Dodge", width=carWidth, height=carHeight} )
--
print( "car.get: " .. tostring( loader.callFunction ("car","get") ) )
loader.callFunction ("car","set","something")
print()
--
print( "car1.getName: " .. tostring( loader.callFunction (car1,"getName") ) )
print( "car2.getName: " .. tostring( loader.callFunction (car2,"getName") ) )
print()
--
loader.callFunction ( car1,"setName","Volkswagen" )
loader.callFunction ( car2,"setName","Fiat" )
--
print( "car1.getName: " .. tostring( loader.callFunction (car1,"getName") ) )
print( "car2.getName: " .. tostring( loader.callFunction (car2,"getName") ) )
print()
--]]



----------------------------------------------------------------------------------------------------------------
-- New Group ( Object )
----------------------------------------------------------------------------------------------------------------
--
-- This sample shows how to create an object that has
-- display content.
--
----------------------------------------------------------------------------------------------------------------

--[[
--loader.debug = true
print()
--
local carImg, carName, carWidth, carHeight = "car.jpg", "Camaro", 200, 100
--
loader.loadImage( carImg )
--
local car = loader.newGroup( "car" , {image=carImg, name=carName, width=carWidth, height=carHeight} )
print ( car.name )
--
car.setName( "Mustang" )
print ( car.getName() )
--
car.x = _W / 2
car.y = _H / 2
--
--]]



----------------------------------------------------------------------------------------------------------------
-- Object Orientation - Reference
----------------------------------------------------------------------------------------------------------------
--
-- This sample shows 3 variables referencing 2 objects.
-- As you can see, objects 1 and 3 are exactly the same.
--
----------------------------------------------------------------------------------------------------------------

--[[
--loader.debug = true
print()
--
local carImg, carName, carWidth, carHeight = "car.jpg", "auto", 200, 100
--
local car1 = loader.newGroup( "car" , {image=carImg, name="Audi",     width=carWidth, height=carHeight} )
local car2 = loader.newGroup( "car" , {image=carImg, name="Porsche",  width=carWidth, height=carHeight} )
local car3 = car1
--
print( "car1: " .. tostring( loader.callFunction (car1,"getName") ) )
print( "car2: " .. tostring( loader.callFunction (car2,"getName") ) )
print( "car3: " .. tostring( loader.callFunction (car3,"getName") ) )
print()
--
loader.callFunction (car1,"setName","Lamborghini")
--
print( "car1: " .. tostring( loader.callFunction (car1,"getName") ) )
print( "car2: " .. tostring( loader.callFunction (car2,"getName") ) )
print( "car3: " .. tostring( loader.callFunction (car3,"getName") ) )
print()
--
loader.callFunction (car3,"setName","Ferrari")
--
print( "car1: " .. tostring( loader.callFunction (car1,"getName") ) )
print( "car2: " .. tostring( loader.callFunction (car2,"getName") ) )
print( "car3: " .. tostring( loader.callFunction (car3,"getName") ) )
print()
--]]